import * as cdk from '@aws-cdk/core';
/**
 * A market order is a request to buy or sell a security at the currently available market price.
 *
 * The order to buy a security will be submitted on resource creation and the security will be sold (or the unfilled order cancelled) on resource deletion. Supported exchanges are AMEX, ARCA, BATS, NYSE, NASDAQ and NYSEARCA.
 *
 * @schema CfnMarketorderProps
 */
export interface CfnMarketorderProps {
    /**
     * The number of shares to buy.
     *
     * @schema CfnMarketorderProps#Quantity
     */
    readonly quantity: number;
    /**
     * The stock symbol to buy.
     *
     * @schema CfnMarketorderProps#Symbol
     */
    readonly symbol: string;
    /**
     * A fields for notes about the order.
     *
     * This field may also be used to force a resource update in order to retrieve the latest market value of the position.
     *
     * @schema CfnMarketorderProps#Notes
     */
    readonly notes?: string;
}
/**
 * Converts an object of type 'CfnMarketorderProps' to JSON representation.
 */
export declare function toJson_CfnMarketorderProps(obj: CfnMarketorderProps | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `Stocks::Orders::MarketOrder`.
 *
 * @external
 * @cloudformationResource Stocks::Orders::MarketOrder
 * @link https://github.com/iann0036/cfn-types/tree/master/stocks-orders-marketorder
 */
export declare class CfnMarketorder extends cdk.CfnResource {
    /**
     * The CloudFormation resource type name for this resource class.
     *
     * @external
     */
    static readonly CFN_RESOURCE_TYPE_NAME = "Stocks::Orders::MarketOrder";
    /**
     * Resource props.
     *
     * @external
     */
    readonly props: CfnMarketorderProps;
    /**
     * Attribute `Stocks::Orders::MarketOrder.Id`.
     *
     * @external
     * @link https://github.com/iann0036/cfn-types/tree/master/stocks-orders-marketorder
     */
    readonly attrId: string;
    /**
     * Attribute `Stocks::Orders::MarketOrder.FilledQuantity`.
     *
     * @external
     * @link https://github.com/iann0036/cfn-types/tree/master/stocks-orders-marketorder
     */
    readonly attrFilledQuantity: string;
    /**
     * Attribute `Stocks::Orders::MarketOrder.FilledValue`.
     *
     * @external
     * @link https://github.com/iann0036/cfn-types/tree/master/stocks-orders-marketorder
     */
    readonly attrFilledValue: string;
    /**
     * Attribute `Stocks::Orders::MarketOrder.CurrentValue`.
     *
     * @external
     * @link https://github.com/iann0036/cfn-types/tree/master/stocks-orders-marketorder
     */
    readonly attrCurrentValue: string;
    /**
     * Attribute `Stocks::Orders::MarketOrder.FilledAt`.
     *
     * @external
     * @link https://github.com/iann0036/cfn-types/tree/master/stocks-orders-marketorder
     */
    readonly attrFilledAt: string;
    /**
     * Create a new `Stocks::Orders::MarketOrder`.
     *
     * @param scope - scope in which this resource is defined.
     * @param id - scoped id of the resource.
     * @param props - resource properties.
     * @external
     */
    constructor(scope: cdk.Construct, id: string, props: CfnMarketorderProps);
}
